==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebGridDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { WebGridBaseDirectiveDescription } from "./WebGridBaseDirectiveDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebGridDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridDescription, _super);
    function WebGridDescription() {
        var _this = _super.call(this) || this;
        _this.hh = false;
        _this.hv = null;
        _this.ht = null;
        _this.h0 = null;
        _this.hb = null;
        _this.hs = null;
        _this.hp = null;
        _this.hn = 0;
        _this.ha = null;
        _this.g9 = null;
        _this.hi = false;
        _this.hf = null;
        _this.hu = null;
        _this.hx = null;
        _this.hz = null;
        _this.hw = null;
        _this.hj = false;
        _this.hr = null;
        _this.hy = null;
        return _this;
    }
    WebGridDescription.prototype.get_type = function () {
        return "WebGrid";
    };
    Object.defineProperty(WebGridDescription.prototype, "groupsExpanded", {
        get: function () {
            return this.hh;
        },
        set: function (a) {
            this.hh = a;
            this.e("GroupsExpanded");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "dropAreaTemplateRef", {
        get: function () {
            return this.hv;
        },
        set: function (a) {
            this.hv = a;
            this.e("DropAreaTemplateRef");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "detailTemplateRef", {
        get: function () {
            return this.ht;
        },
        set: function (a) {
            this.ht = a;
            this.e("DetailTemplateRef");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "id", {
        get: function () {
            return this.h0;
        },
        set: function (a) {
            this.h0 = a;
            this.e("Id");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "groupsRecords", {
        get: function () {
            return this.hb;
        },
        set: function (a) {
            this.hb = a;
            this.e("GroupsRecords");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "dataRef", {
        get: function () {
            return this.hs;
        },
        set: function (a) {
            this.hs = a;
            this.e("DataRef");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "filteredData", {
        get: function () {
            return this.hp;
        },
        set: function (a) {
            this.hp = a;
            this.e("FilteredData");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "totalItemCount", {
        get: function () {
            return this.hn;
        },
        set: function (a) {
            this.hn = a;
            this.e("TotalItemCount");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "groupingExpressions", {
        get: function () {
            return this.ha;
        },
        set: function (a) {
            this.ha = a;
            this.e("GroupingExpressions");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "groupingExpansionState", {
        get: function () {
            return this.g9;
        },
        set: function (a) {
            this.g9 = a;
            this.e("GroupingExpansionState");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "hideGroupedColumns", {
        get: function () {
            return this.hi;
        },
        set: function (a) {
            this.hi = a;
            this.e("HideGroupedColumns");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "groupStrategy", {
        get: function () {
            return this.hf;
        },
        set: function (a) {
            this.hf = a;
            this.e("GroupStrategy");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "dropAreaMessage", {
        get: function () {
            return this.hu;
        },
        set: function (a) {
            this.hu = a;
            this.e("DropAreaMessage");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "groupByRowSelectorTemplateRef", {
        get: function () {
            return this.hx;
        },
        set: function (a) {
            this.hx = a;
            this.e("GroupByRowSelectorTemplateRef");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "groupRowTemplateRef", {
        get: function () {
            return this.hz;
        },
        set: function (a) {
            this.hz = a;
            this.e("GroupRowTemplateRef");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "groupAreaTemplateRef", {
        get: function () {
            return this.hw;
        },
        set: function (a) {
            this.hw = a;
            this.e("GroupAreaTemplateRef");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "showGroupArea", {
        get: function () {
            return this.hj;
        },
        set: function (a) {
            this.hj = a;
            this.e("ShowGroupArea");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "dataPreLoadRef", {
        get: function () {
            return this.hr;
        },
        set: function (a) {
            this.hr = a;
            this.e("DataPreLoadRef");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "groupingDoneRef", {
        get: function () {
            return this.hy;
        },
        set: function (a) {
            this.hy = a;
            this.e("GroupingDoneRef");
        },
        enumerable: true,
        configurable: true
    });
    WebGridDescription.$t = markType(WebGridDescription, 'WebGridDescription', WebGridBaseDirectiveDescription.$);
    return WebGridDescription;
}(WebGridBaseDirectiveDescription));
export { WebGridDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebGridDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { WebGridBaseDirectiveDescription } from "./WebGridBaseDirectiveDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebGridDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridDescription, _super);
    function WebGridDescription() {
        var _this = _super.call(this) || this;
        _this.gv = false;
        _this.g7 = null;
        _this.g5 = null;
        _this.hb = null;
        _this.g4 = null;
        _this.g1 = 0;
        _this.gq = null;
        _this.gp = null;
        _this.gw = false;
        _this.gt = null;
        _this.g6 = null;
        _this.g8 = null;
        _this.ha = null;
        _this.gx = false;
        _this.g3 = null;
        _this.g9 = null;
        return _this;
    }
    WebGridDescription.prototype.get_type = function () {
        return "WebGrid";
    };
    Object.defineProperty(WebGridDescription.prototype, "groupsExpanded", {
        get: function () {
            return this.gv;
        },
        set: function (a) {
            this.gv = a;
            this.g("GroupsExpanded");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "dropAreaTemplateRef", {
        get: function () {
            return this.g7;
        },
        set: function (a) {
            this.g7 = a;
            this.g("DropAreaTemplateRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "detailTemplateRef", {
        get: function () {
            return this.g5;
        },
        set: function (a) {
            this.g5 = a;
            this.g("DetailTemplateRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "id", {
        get: function () {
            return this.hb;
        },
        set: function (a) {
            this.hb = a;
            this.g("Id");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "dataRef", {
        get: function () {
            return this.g4;
        },
        set: function (a) {
            this.g4 = a;
            this.g("DataRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "totalItemCount", {
        get: function () {
            return this.g1;
        },
        set: function (a) {
            this.g1 = a;
            this.g("TotalItemCount");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "groupingExpressions", {
        get: function () {
            return this.gq;
        },
        set: function (a) {
            this.gq = a;
            this.g("GroupingExpressions");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "groupingExpansionState", {
        get: function () {
            return this.gp;
        },
        set: function (a) {
            this.gp = a;
            this.g("GroupingExpansionState");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "hideGroupedColumns", {
        get: function () {
            return this.gw;
        },
        set: function (a) {
            this.gw = a;
            this.g("HideGroupedColumns");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "groupStrategy", {
        get: function () {
            return this.gt;
        },
        set: function (a) {
            this.gt = a;
            this.g("GroupStrategy");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "dropAreaMessage", {
        get: function () {
            return this.g6;
        },
        set: function (a) {
            this.g6 = a;
            this.g("DropAreaMessage");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "groupByRowSelectorTemplateRef", {
        get: function () {
            return this.g8;
        },
        set: function (a) {
            this.g8 = a;
            this.g("GroupByRowSelectorTemplateRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "groupRowTemplateRef", {
        get: function () {
            return this.ha;
        },
        set: function (a) {
            this.ha = a;
            this.g("GroupRowTemplateRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "showGroupArea", {
        get: function () {
            return this.gx;
        },
        set: function (a) {
            this.gx = a;
            this.g("ShowGroupArea");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "dataPreLoadRef", {
        get: function () {
            return this.g3;
        },
        set: function (a) {
            this.g3 = a;
            this.g("DataPreLoadRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridDescription.prototype, "groupingDoneRef", {
        get: function () {
            return this.g9;
        },
        set: function (a) {
            this.g9 = a;
            this.g("GroupingDoneRef");
        },
        enumerable: false,
        configurable: true
    });
    WebGridDescription.$t = markType(WebGridDescription, 'WebGridDescription', WebGridBaseDirectiveDescription.$);
    return WebGridDescription;
}(WebGridBaseDirectiveDescription));
export { WebGridDescription };
